function addSwatchToPhotoshop(swatch) {
    var addColorAction = new ActionDescriptor();

    // Get reference to Swatches panel
    var swatchesPanelReference = new ActionReference();
    swatchesPanelReference.putClass(stringIDToTypeID('colors'));
    addColorAction.putReference(stringIDToTypeID('null'), swatchesPanelReference);

    // Add swatch to the color descriptor
    addColorAction.putObject(stringIDToTypeID('using'), stringIDToTypeID('colors'), swatch);

    // Send to Photoshop
    executeAction(stringIDToTypeID('make'), addColorAction, DialogModes.NO);
}

function createCMYKColorSwatch(colorName, cyan, magenta, yellow, black) {
    // Setup a swatch and give it a name
    var swatch = new ActionDescriptor();
    swatch.putString(stringIDToTypeID('name'), colorName);

    // Add RGB color information to the swatch
    var color = new ActionDescriptor();
    color.putDouble(stringIDToTypeID('cyan'), cyan);
    color.putDouble(stringIDToTypeID('magenta'), magenta);
    color.putDouble(stringIDToTypeID('yellow'), yellow);
    color.putDouble(stringIDToTypeID('black'), black);

    // Add color to the swatch
    swatch.putObject(stringIDToTypeID('color'), stringIDToTypeID('CMYKColor'), color);

    return swatch;
}

function createGrayColorSwatch(colorName, gray) {
    // Setup a swatch and give it a name
    var swatch = new ActionDescriptor();
    swatch.putString(stringIDToTypeID('name'), colorName);

    // Add RGB color information to the swatch
    var color = new ActionDescriptor();
    color.putDouble(stringIDToTypeID('gray'), gray);

    // Add color to the swatch
    swatch.putObject(stringIDToTypeID('color'), stringIDToTypeID('GrayColor'), color);

    return swatch;
}

function createHSBColorSwatch(colorName, hue, saturation, brightness) {
    // Setup a swatch and give it a name
    var swatch = new ActionDescriptor();
    swatch.putString(stringIDToTypeID('name'), colorName);

    // Add RGB color information to the swatch
    var color = new ActionDescriptor();
    color.putDouble(stringIDToTypeID('hue'), hue);
    color.putDouble(stringIDToTypeID('saturation'), saturation);
    color.putDouble(stringIDToTypeID('brightness'), brightness);

    // Add color to the swatch
    swatch.putObject(stringIDToTypeID('color'), stringIDToTypeID('HSBColor'), color);

    return swatch;
}

function createLABColorSwatch(colorName, l, a, b) {
    // Setup a swatch and give it a name
    var swatch = new ActionDescriptor();
    swatch.putString(stringIDToTypeID('name'), colorName);

    // Add RGB color information to the swatch
    var color = new ActionDescriptor();
    color.putDouble(stringIDToTypeID('l'), l);
    color.putDouble(stringIDToTypeID('a'), a);
    color.putDouble(stringIDToTypeID('b'), b);

    // Add color to the swatch
    swatch.putObject(stringIDToTypeID('color'), stringIDToTypeID('LabColor'), color);

    return swatch;
}

function createRGBColorSwatch(colorName, red, green, blue) {
    // Setup a swatch and give it a name
    var swatch = new ActionDescriptor();
    swatch.putString(stringIDToTypeID('name'), colorName);

    // Add RGB color information to the swatch
    var color = new ActionDescriptor();
    color.putDouble(stringIDToTypeID('red'), red);
    color.putDouble(stringIDToTypeID('green'), green);
    color.putDouble(stringIDToTypeID('blue'), blue);

    // Add color to the swatch
    swatch.putObject(stringIDToTypeID('color'), stringIDToTypeID('RGBColor'), color);

    return swatch;
}

function createColorSwatchFromArguments(arguments) {
    var name = arguments[0];
    var format = arguments[1];

    var swatch;

    if (format === "CMYKColor") {
        swatch = createCMYKColorSwatch(name, arguments[2], arguments[3], arguments[4], arguments[5]);
    } else if (format === "GrayColor") {
        swatch = createGrayColorSwatch(name, arguments[2]);
    } else if (format === "HSBColor") {
        swatch = createHSBColorSwatch(name, arguments[2], arguments[3], arguments[4]);
    } else if (format === "LabColor") {
        swatch = createLabColorSwatch(name, arguments[2], arguments[3], arguments[4]);
    } else if (format === "RGBColor") {
        swatch = createRGBColorSwatch(name, arguments[2], arguments[3], arguments[4]);
    }
    
    return swatch;
}


var swatch = createColorSwatchFromArguments(arguments);
addSwatchToPhotoshop(swatch);
